@@ -112,7 +112,7 @@ C<excl> would fail by open the log file if the log file already exists.
 C<trunc> would truncate the complete log file if it exists. Please take care
 to use this option.
 
-Take a look to the documentation of C<sysopen()> to get more informations.
+Take a look to the documentation of C<sysopen()> to get more information.
 
 =item B<autoflush>
 
@@ -130,7 +130,7 @@ C<0640> is the default permission for this option. That means that the owner
 got read and write permissions and users in the same group got only read
 permissions. All other users got no access.
 
-Take a look to the documentation of C<sysopen()> to get more informations.
+Take a look to the documentation of C<sysopen()> to get more information.
 
 =item B<utf8>
 
@@ -155,6 +155,14 @@ This is useful if you don't want to use option S<"reopen">. As example
 if a rotate mechanism moves the logfile and you want to re-open a new
 one.
 
+=head2 validate()
+
+Validate a configuration.
+
+=head2 reload()
+
+Reload with a new configuration.
+
 =head2 errstr()
 
 Call C<errstr()> to get the last error message.
@@ -187,7 +195,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2008 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -203,27 +211,13 @@ use Fcntl qw( :flock O_WRONLY O_APPEND O_TRUNC O_EXCL O_CREAT );
 use File::Spec;
 use Params::Validate qw();
 
-our $VERSION = "0.04";
+our $VERSION = "0.06";
 our $ERRSTR  = "";
 
 sub new {
-    my $class   = shift;
-    my $options = $class->_validate(@_);
-    my $self    = bless $options, $class;
-
-    if (ref($self->{filename}) eq "ARRAY") {
-        $self->{filename} = File::Spec->catfile(@{$self->{filename}});
-    }
-
-    if ($self->{mode} eq "append") {
-        $self->{mode} = O_WRONLY | O_APPEND | O_CREAT;
-    } elsif ($self->{mode} eq "excl") {
-        $self->{mode} = O_WRONLY | O_EXCL | O_CREAT;
-    } elsif ($self->{mode} eq "trunc") {
-        $self->{mode} = O_WRONLY | O_TRUNC | O_CREAT;
-    }
-
-    $self->{permissions} = oct($self->{permissions});
+    my $class = shift;
+    my $opts  = $class->_validate(@_);
+    my $self  = bless $opts, $class;
 
     # open the log file permanent
     if ($self->{fileopen}) {
@@ -287,7 +281,40 @@ sub close {
     return 1;
 }
 
-sub errstr { $ERRSTR }
+sub validate {
+    my $self = shift;
+    my $opts = ();
+
+    eval { $opts = $self->_validate(@_) };
+
+    if ($@) {
+        return $self->_raise_error($@);
+    }
+
+    return $opts;
+}
+
+sub reload {
+    my $self = shift;
+    my $opts = $self->validate(@_);
+
+    $self->close;
+
+    foreach my $key (keys %$opts) {
+        $self->{$key} = $opts->{$key};
+    }
+
+    if ($self->{fileopen}) {
+        $self->_open
+            or croak $self->errstr;
+    }
+
+    return 1;
+}
+
+sub errstr {
+    return $ERRSTR;
+}
 
 sub DESTROY {
     my $self = shift;
@@ -340,7 +367,7 @@ sub _validate {
     my $class   = shift;
     my $bool_rx = qr/^[10]\z/;
 
-    my %options = Params::Validate::validate(@_, {
+    my %opts = Params::Validate::validate(@_, {
         filename => {
             type => Params::Validate::SCALAR | Params::Validate::ARRAYREF,
         },
@@ -381,7 +408,21 @@ sub _validate {
         },
     });
 
-    return \%options;
+    if (ref($opts{filename}) eq "ARRAY") {
+        $opts{filename} = File::Spec->catfile(@{$opts{filename}});
+    }
+
+    if ($opts{mode} eq "append") {
+        $opts{mode} = O_WRONLY | O_APPEND | O_CREAT;
+    } elsif ($opts{mode} eq "excl") {
+        $opts{mode} = O_WRONLY | O_EXCL | O_CREAT;
+    } elsif ($opts{mode} eq "trunc") {
+        $opts{mode} = O_WRONLY | O_TRUNC | O_CREAT;
+    }
+
+    $opts{permissions} = oct($opts{permissions});
+
+    return \%opts;
 }
 
 sub _raise_error {
